﻿using System;
using System.Net;
using System.Threading.Tasks;
using System.Windows;
using Async.Workers;
using System.Collections.ObjectModel;

namespace Async
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		IDoWork _worker;

		public MainWindow()
		{
			InitializeComponent();
		}

		private async void LoadImages_Click(object sender, RoutedEventArgs e)
		{
			ObservableCollection<FlickrImage> images = new ObservableCollection<FlickrImage>();
			Images.ItemsSource = images;

			_worker = new TheBadWay();
//			_worker = new TheOldWay();
//			_worker = new TheNewWay();
//			_worker = new TheWaitingWay();
//			_worker = new TheCancellationWay();
//          _worker = new TheParallelWay();
//			_worker = new TheTaskRunWay();
//			_worker = new TheConfigureAwaitWay();

			/*await*/ _worker.DoWorkAsync(images);
		}

		private void Cancel_Click(object sender, RoutedEventArgs e)
		{
			_worker.Cancel();
		}




		private async void BeginEnd_Click(object sender, RoutedEventArgs e)
		{
			IPHostEntry ipHostEntry = await Task<IPHostEntry>.Factory.FromAsync(Dns.BeginGetHostEntry, Dns.EndGetHostEntry, "brianpeek.com", null); 
			MessageBox.Show(ipHostEntry.AddressList[0].ToString());
		}

		private async void EventTask_Click(object sender, RoutedEventArgs e)
		{
			try
			{
				string s = await GetTimeAsync();
				MessageBox.Show(s);
			}
			catch(Exception ex)
			{
				MessageBox.Show(ex.ToString());
			}
		}

		private Task<string> GetTimeAsync()
		{
			TaskCompletionSource<string> tcs = new TaskCompletionSource<string>();
			WebClient wc = new WebClient();
			wc.DownloadStringCompleted += (s, args) =>
			{
				if(args.Error != null)
					tcs.SetException(args.Error);
				else if(args.Cancelled)
					tcs.SetCanceled();
				else
					tcs.SetResult(args.Result);
			};
			wc.DownloadStringAsync(new Uri("http://www.fullerdata.com/FortuneCookie/FortuneCookie.asmx/GetFortuneCookie"));
			return tcs.Task;
		}
	}
}
